# import os

# class blmos:
#     def get_files_from_directory(self, dir_path, extension_type=''):
#         files = [f.path for f in os.scandir(dir_path) if f.is_file()]
#         if len(extension_type) > 0:
#             files = [f.path for f in os.scandir(dir_path) if f.is_file() and f.path.endswith('.'+extension_type)]
#         return files
import json

class blmjson:
    def load_json_file(self, filename):
        with open(filename) as f:
            tmp_data = f.read()
            while not (tmp_data[0].startswith('[') or tmp_data[0].startswith('{')):
                tmp_data = tmp_data[1:]
        return json.loads(tmp_data)


        


from setuptools import setup, find_packages

VERSION = '0.0.7' 
DESCRIPTION = 'Bluemanoid Package'
LONG_DESCRIPTION = 'Useful Python scripts for Bluemanoid workers'
AUTHOR = 'Gautier Rio'
AUTHOR_MAIL = 'gautier.rio@bluemanoid.com'

# Setting up
setup(
    name="blmpy", 
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_MAIL,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    
    keywords=['python', 'Bluemanoid', 'BLM'],
    classifiers= [
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)